import { Resource, ResourceProps } from 'aws-cdk-lib';
import { ICertificate } from 'aws-cdk-lib/aws-certificatemanager';
import { ClientVpnUserBasedAuthentication, IClientVpnConnectionHandler, TransportProtocol, VpnPort } from 'aws-cdk-lib/aws-ec2';
import { ILogGroup, ILogStream } from 'aws-cdk-lib/aws-logs';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { IConstruct } from 'constructs';
import { FourTierNetworkHub, IpAddressManager } from '.';
import { FourTierNetworkSpoke } from './four-tier-network-spoke';
import { FlowLogFormat, ITransitGatewayRouteTable } from '../ec2';
import { IIpv4CidrAssignment } from '../ec2/lib/cidr-assignment';
import { GlobalNetwork } from '../networkmanager/global-network';
export interface NetworkControllerProps extends ResourceProps {
    readonly defaultClientVpnNetmask?: number;
    readonly defaultVpcNetmask?: number;
    readonly flowLogBucket?: IBucket;
    readonly flowLogFormat?: FlowLogFormat;
}
export interface AddClientVpnEndpointOptions {
    readonly authorizeAllUsersToVpcCidr?: boolean;
    readonly clientCertificate?: ICertificate;
    readonly clientConnectionHandler?: IClientVpnConnectionHandler;
    readonly clientLoginBanner?: string;
    readonly description?: string;
    readonly dnsServers?: string[];
    readonly logGroup?: ILogGroup;
    readonly logStream?: ILogStream;
    readonly logging?: boolean;
    readonly maxAzs?: number;
    readonly port?: VpnPort;
    readonly selfServicePortal?: boolean;
    readonly serverCertificate: ICertificate;
    readonly splitTunnel?: boolean;
    readonly subnetCidr?: IIpv4CidrAssignment;
    readonly transportProtocol?: TransportProtocol;
    readonly userBasedAuthentication?: ClientVpnUserBasedAuthentication;
    readonly vpnCidr?: IIpv4CidrAssignment;
}
export interface AddNetworkOptions {
    readonly availabilityZones?: string[];
    readonly maxAzs?: number;
    readonly netmask?: number;
}
export interface AddHubOptions extends AddNetworkOptions {
    readonly defaultTransitGatewayRouteTable?: ITransitGatewayRouteTable;
}
export declare class NetworkController extends Resource {
    static readonly DEFAULT_CLIENT_VPN_NETMASK: number;
    private readonly _hubs;
    private readonly _registeredAccounts;
    private readonly _registeredRegions;
    readonly defaultClientVpnNetmask: number;
    readonly defaultNetmask: number;
    readonly flowLogFormat: FlowLogFormat;
    readonly addressManager: IpAddressManager;
    readonly flowLogBucket: IBucket;
    readonly globalNetwork: GlobalNetwork;
    get registeredAccounts(): string[];
    get registeredRegions(): string[];
    constructor(scope: IConstruct, id: string, props?: NetworkControllerProps);
    addClientVpnEndpoint(scope: IConstruct, id: string, options: AddClientVpnEndpointOptions): void;
    addHub(scope: IConstruct, id: string, options?: AddHubOptions): FourTierNetworkHub;
    addSpoke(scope: IConstruct, id: string, options?: AddNetworkOptions): FourTierNetworkSpoke;
    registerCidr(scope: IConstruct, id: string, cidr: string): void;
    protected registerAccount(account: string): void;
    protected registerRegion(region: string): void;
}
