import { CfnTransitGatewayAttachment } from 'aws-cdk-lib/aws-ec2';
import { Construct, IConstruct } from 'constructs';
import { ITransitGatewayAttachment, TransitGatewayAttachmentResource, TransitGatewayAttachmentResourceProps } from './transit-gateway-attachment-base';
/**
 * Configuration for TransitGatewayAttachment resource.
 */
export interface TransitGatewayAttachmentProps extends TransitGatewayAttachmentResourceProps {
}
/**
 * Attaches a VPC to a transit gateway.
 *
 * If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC
 * that is already attached, the new VPC CIDR range is not propagated to the
 * default propagation route table.
 */
export declare class TransitGatewayAttachment extends TransitGatewayAttachmentResource {
    /**
     * Imports an existing Transit Gateway Attachment using its attachment ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param transitGatewayAttachmentId The attachment ID of the Transit Gateway
     * attachment being imported.
     * @returns An object representing the imported transit gateway attachment.
     */
    static fromTransitGatewayAttachmentId(scope: IConstruct, id: string, transitGatewayAttachmentId: string): ITransitGatewayAttachment;
    /**
     * The underlying NamedQuery CloudFormation resource.
     *
     * @see [AWS::EC2::TransitGatewayVpcAttachment](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-transitgatewayvpcattachment.html)
     *
     * @group Resources
     */
    readonly resource: CfnTransitGatewayAttachment;
    /**
     * The ARN of this Transit Gateway Attachment.
     */
    readonly transitGatewayAttachmentArn: string;
    /**
     * The ID of this Transit Gateway Attachment.
     */
    readonly transitGatewayAttachmentId: string;
    /**
     * Creates a new instance of the TransitGatewayAttachment class.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in the construct tree.
     * @param id A name to be associated with the stack and used in resource naming. Must be unique
     * within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: Construct, id: string, props: TransitGatewayAttachmentProps);
}
